ApiService class

Constructors

ApiService()

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAppStatus(String appName) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAppStatus(String appName, bool isEnabled) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

timeoutDuration → const int